.. _models-link:

Models
******

.. toctree::
   :maxdepth: 4
   :hidden:

   models/chung_everhart
   models/dionne_3d
   models/sombrin
   models/vaughan

.. include:: models/chung_everhart.rst
.. include:: models/dionne_3d.rst
.. include:: models/sombrin.rst
.. include:: models/vaughan.rst
